@@ -9,6 +9,7 @@ from typing import Any, Dict, List, Optional, Set, Tuple
 import pandas as pd
 from mitosheet.code_chunks.code_chunk import CodeChunk
 from mitosheet.code_chunks.step_performers.import_steps.excel_import_code_chunk import ExcelImportCodeChunk
+from mitosheet.step_performers.utils import get_param
 
 from mitosheet.utils import get_valid_dataframe_name
 from mitosheet.state import DATAFRAME_SOURCE_IMPORTED, State
@@ -30,20 +31,12 @@ class ExcelImportStepPerformer(StepPerformer):
         return 'excel_import'
 
     @classmethod
-    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
-        return params
+    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
+        file_name: str = get_param(params, 'file_name')
+        sheet_names: List[str] = get_param(params, 'sheet_names')
+        has_headers: bool = get_param(params, 'has_headers')
+        skiprows: int = get_param(params, 'skiprows')
 
-    @classmethod
-    def execute( # type: ignore
-        cls,
-        prev_state: State,
-        file_name: str,
-        sheet_names: List[str],
-        has_headers: bool,
-        skiprows: int,
-        **params
-    ) -> Tuple[State, Optional[Dict[str, Any]]]:
-        # Create a new step
         post_state = prev_state.copy()
 
         read_excel_params = {
@@ -83,12 +76,5 @@ class ExcelImportStepPerformer(StepPerformer):
         ]
 
     @classmethod
-    def get_modified_dataframe_indexes( # type: ignore
-        cls, 
-        file_name: str,
-        sheet_names: List[str],
-        has_headers: bool,
-        use_deprecated_id_algorithm: bool=False,
-        **params
-    ) -> Set[int]:
-        return {-1} # changes the new dataframe(s - there might be multiple made in this step)
\ No newline at end of file
+    def get_modified_dataframe_indexes(cls, params: Dict[str, Any]) -> Set[int]:
+        return {-1}
\ No newline at end of file
